# Thread

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**history_id** | **str** | The ID of the last history record that modified this thread. | [optional] 
**id** | **str** | The unique ID of the thread. | [optional] 
**messages** | [**list[Message]**](Message.md) | The list of messages in the thread. | [optional] 
**snippet** | **str** | A short part of the message text. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

